@@ -20,6 +20,9 @@ pub enum SubCommand {
 
 	#[clap(version = crate_version!(), author = crate_authors!())]
 	Open(OpenOpts),
+
+	#[clap(version = crate_version!(), author = crate_authors!())]
+	Search(SearchOpts),
 }
 
 /// The `info` command returns summarized information
@@ -53,3 +56,23 @@ pub struct OpenOpts {
 	#[clap(long, alias("doc"))]
 	pub documentation: bool,
 }
+
+fn valid_page_size(v: &str) -> Result<(), String> {
+	let i = v.parse::<u64>().expect("Failed parsing number");
+	if i <= 100 {
+		return Ok(());
+	}
+	Err(String::from("The page size must be 0..100"))
+}
+
+/// The `search` command returns a list of crates matching your search pattern
+#[derive(Parser, Debug)]
+pub struct SearchOpts {
+	/// You search pattern
+	#[clap(index = 1)]
+	pub pattern: String,
+
+	/// Number of expected results: 0..100
+	#[clap(short, long, default_value("32"), validator(valid_page_size))]
+	pub limit: u64,
+}
